@@ -8,56 +8,74 @@ $VAR1 = {
           'defaultAction' => 'news',
           'files' => {
                        'owner' => 'linse',
-                       'group' => 'wwwrun',
+                       'group' => 'users',
                        'chmod' => '0755'
                      },
           'size' => 22,
           'uploads' => {
                          'maxlength' => 2003153,
-                         'right' => 4,
+                         'right' => 5,
                          'path' => '/srv/www//htdocs/downloads/',
                          'chmod' => 420,
                          'enabled' => 1
                        },
-          'floodtime' => 5,
+          'floodtime' => 10,
           'session' => '/srv/www/cgi-bin/config/session.pl',
           'scriptAlias' => 'cgi-bin',
+          'sign' => 1,
           'admin' => {
-                       'firstname' => 'Firstname',
+                       'firstname' => 'Max',
+                       'number' => '',
+                       'postocde' => '',
+                       'street' => '',
+                       'town' => 'Berlin',
+                       'msn' => '',
+                       'jahoo' => '',
                        'email' => 'your@email.org',
-                       'street' => 'example 33',
-                       'name' => 'Name',
-                       'town' => 'Berlin'
+                       'icq' => '',
+                       'tel' => '',
+                       'postcode' => '10965',
+                       'country' => 'Deutschland',
+                       'name' => 'Musterman',
+                       'tonwn' => 'Berlin',
+                       'aim' => '',
+                       'signature' => '',
+                       'skype' => '',
+                       'jabber' => ''
                      },
           'language' => 'en',
-          'version' => '0.36',
+          'version' => '0.37',
           'cgi' => {
                      'bin' => '/srv/www/cgi-bin',
-                     'style' => 'Crystal',
+                     'style' => 'lze',
                      'serverName' => 'localhost',
                      'cookiePath' => '/',
-                     'title' => 'CGI::CMS',
+                     'title' => 'Lindnerei',
                      'mod_rewrite' => '1',
                      'alias' => 'cgi-bin',
                      'DocumentRoot' => '/srv/www//htdocs',
                      'expires' => '+1y'
                    },
           'database' => {
+                          'CurrentUser' => 'root',
+                          'name' => 'LZE',
+                          'CurrentPass' => '',
+                          'host' => 'localhost',
                           'password' => '',
                           'user' => 'root',
-                          'name' => 'LZE',
-                          'host' => 'localhost'
+                          'CurrentDb' => 'LZE',
+                          'CurrentHost' => 'localhost'
                         },
           'sidebar' => {
-                         'left' => 1,
+                         'left' => 0,
                          'right' => 1
                        },
           'translate' => '/srv/www/cgi-bin/config/translate.pl',
           'config' => '/srv/www/cgi-bin/config/settings.pl',
           'news' => {
                       'maxlength' => 5000,
-                      'right' => 4,
+                      'right' => 5,
                       'messages' => 10
                     }
         };
-$settings =$VAR1;
\ No newline at end of file
+$m_hrSettings =$VAR1;
\ No newline at end of file
