@@ -2,13 +2,15 @@ package CGI::CMS::Translate;
 use strict;
 use warnings;
 require Exporter;
-use vars qw($ACCEPT_LANGUAGE $lang $DefaultClass @EXPORT  @ISA $defaultconfig);
+use vars
+    qw($ACCEPT_LANGUAGE $lang $DefaultClass @EXPORT  @ISA $defaultconfig);
 @CGI::CMS::Translate::EXPORT = qw(loadTranslate saveTranslate $lang);
 use CGI::CMS::Config;
 @ISA                          = qw(Exporter CGI::CMS::Config);
-$CGI::CMS::Translate::VERSION = '0.36';
-$DefaultClass                 = 'CGI::CMS::Translate' unless defined $CGI::CMS::Translate::DefaultClass;
-$defaultconfig                = '%CONFIG%';
+$CGI::CMS::Translate::VERSION = '0.37';
+$DefaultClass                 = 'CGI::CMS::Translate'
+    unless defined $CGI::CMS::Translate::DefaultClass;
+$defaultconfig = '%CONFIG%';
 
 =head1 NAME
 
@@ -41,7 +43,7 @@ loadTranslate() saveTranslate() $lang
 =cut
 
 sub new {
-    my ($class, @initializer) = @_;
+    my ( $class, @initializer ) = @_;
     my $self = {};
     bless $self, ref $class || $class || $DefaultClass;
     return $self;
@@ -52,9 +54,9 @@ sub new {
 =cut
 
 sub loadTranslate {
-    my ($self, @p) = getSelf(@_);
-    my $do = (defined $p[0]) ? $p[0] : $defaultconfig;
-    if(-e $do) {
+    my ( $self, @p ) = getSelf(@_);
+    my $do = ( defined $p[0] ) ? $p[0] : $defaultconfig;
+    if( -e $do ) {
         do $do;
     }
 }
@@ -64,9 +66,9 @@ sub loadTranslate {
 =cut
 
 sub saveTranslate {
-    my ($self, @p) = getSelf(@_);
+    my ( $self, @p ) = getSelf(@_);
     my $l = defined $p[0] ? $p[0] : $defaultconfig;
-    $self->SUPER::saveConfig($l, $lang, 'lang');
+    $self->SUPER::saveConfig( $l, $lang, 'lang' );
 }
 
 =head1 Private
@@ -76,8 +78,15 @@ sub saveTranslate {
 =cut
 
 sub getSelf {
-    return @_ if defined($_[0]) && (!ref($_[0])) && ($_[0] eq 'CGI::CMS::Translate');
-    return (defined($_[0]) && (ref($_[0]) eq 'CGI::CMS::Translate' || UNIVERSAL::isa($_[0], 'CGI::CMS::Translate'))) ? @_ : ($CGI::CMS::Translate::DefaultClass->new, @_);
+    return @_
+        if defined( $_[0] )
+            && ( !ref( $_[0] ) )
+            && ( $_[0] eq 'CGI::CMS::Translate' );
+    return (
+        defined( $_[0] )
+            && ( ref( $_[0] ) eq 'CGI::CMS::Translate'
+            || UNIVERSAL::isa( $_[0], 'CGI::CMS::Translate' ) )
+    ) ? @_ : ( $CGI::CMS::Translate::DefaultClass->new, @_ );
 }
 
 =head2 see Also
