@@ -5,7 +5,7 @@ use vars qw(@EXPORT @ISA $currentstring @formatString);
 require Exporter;
 @HTML::Editor::BBCODE::EXPORT  = qw(BBCODE);
 @ISA                           = qw(Exporter);
-$HTML::Editor::BBCODE::VERSION = '0.36';
+$HTML::Editor::BBCODE::VERSION = '0.37';
 use HTML::Entities;
 
 =head1 NAME
@@ -152,7 +152,8 @@ sub BBCODE {
     my $ACCEPT_LANGUAGE = shift;
     $ACCEPT_LANGUAGE = defined $ACCEPT_LANGUAGE ? $ACCEPT_LANGUAGE : 'de';
     my $rplc;
-    $$string =~ s/\[(code)=(Perl|Java|C\+\+|XML|Ruby|Python|PHP|JavaScript|HTML|CSS|Bash)\](.*?)\[\/code\]/formatString($3,$2)/egs;
+    $$string
+        =~ s/\[(code)=(Perl|Java|C\+\+|XML|Ruby|Python|PHP|JavaScript|HTML|CSS|Bash)\](.*?)\[\/code\]/formatString($3,$2)/egs;
     $$string =~ s/\[code\](.*?)\[\/code\]/formatString($1,'Perl')/egs;
     $$string = encode_entities($$string);
     $$string =~ s:\[(u)\](.*?)\[/\1\]:<$1>$2</$1>:gs;
@@ -171,26 +172,33 @@ sub BBCODE {
     $$string =~ s/\[(sub)\](.*?)\[\/\1\]/<$1>$2<\/$1>/gs;
     $$string =~ s/\[(sup)\](.*?)\[\/\1\]/<$1>$2<\/$1>/gs;
     $$string =~ s/\[hr\]/<hr\/>/gs;
-    $$string =~ s/\[color=(.*?)\](.*?)\[\/color\]/<span style="color:$1;background-color:#E6DADE;">$2<\/span>/gs;
+    $$string
+        =~ s/\[color=(.*?)\](.*?)\[\/color\]/<span style="color:$1;background-color:#E6DADE;">$2<\/span>/gs;
     $$string =~ s/\[right\](.*?)\[\/right\]/<div align="right">$1<\/div>/gs;
-    $$string =~ s/\[center\](.*?)\[\/center\]/<div align="center">$1<\/div>/gs;
+    $$string
+        =~ s/\[center\](.*?)\[\/center\]/<div align="center">$1<\/div>/gs;
     $$string =~ s/\[left\](.*?)\[\/left\]/<div align="left">$1<\/div>/gs;
-    $$string =~ s/\[url=(.*?)\](.*?)\[\/url\]/<a style="color:#000000;background-color:#E6DADE;" href="$1">$2<\/a>/gs;
-    $$string =~ s/\[email=(.*?)\](.*?)\[\/email\]/<a style="color:#000000;" target="_blank" href="mailto:$1">$2<\/a>/gs;
+    $$string
+        =~ s/\[url=(.*?)\](.*?)\[\/url\]/<a style="color:#000000;background-color:#E6DADE;" href="$1">$2<\/a>/gs;
+    $$string
+        =~ s/\[email=(.*?)\](.*?)\[\/email\]/<a style="color:#000000;" target="_blank" href="mailto:$1">$2<\/a>/gs;
     $$string =~ s/\[(img)\](.*?)\[\/\1\]/<img border="0" src="$2" alt=""\/>/g;
-    $$string =~ s/\[(google)\](.*?)\[\/\1\]/<a style="color:#000000;" target="_blank" href="http:\/\/www.google.de\/search?q=$2">Google:$2<\/a>/gs;
-    $$string =~
-      s/\[blog=(.*?)\](.*?)\[\/blog\]/<table  cellpadding="0" cellspacing="0" border="0"><tr><td><table  cellpadding="5" cellspacing="0"  border="0" class="blog"><tr><td>$2<\/td><\/tr><\/table><\/td><\/tr><tr><td><b><a href="$1" class="link">Quelle<\/a><\/b><\/td><\/tr><\/table>/gs;
+    $$string
+        =~ s/\[(google)\](.*?)\[\/\1\]/<a style="color:#000000;" target="_blank" href="http:\/\/www.google.de\/search?q=$2">Google:$2<\/a>/gs;
+    $$string
+        =~ s/\[blog=(.*?)\](.*?)\[\/blog\]/<table  cellpadding="0" cellspacing="0" border="0"><tr><td><table  cellpadding="5" cellspacing="0"  border="0" class="blog"><tr><td>$2<\/td><\/tr><\/table><\/td><\/tr><tr><td><b><a href="$1" class="link">Quelle<\/a><\/b><\/td><\/tr><\/table>/gs;
     $$string =~ s/\n/\n<br\/>/ig;
-    $$string =~ s/:\)/<img src="\/images\/smiley.gif" alt=":)" border="0"\/>/g;
+    $$string
+        =~ s/:\)/<img src="\/images\/smiley.gif" alt=":)" border="0"\/>/g;
     $$string =~ s/;D/<img src="\/images\/grin.gif" alt=";D" border="0"\/>/g;
     $$string =~ s/8\)/<img src="\/images\/cool.gif" alt="8)" border="0"\/>/g;
-    $$string =~ s/:-\*/<img src="\/images\/kiss.gif" alt=":-*" border="0"\/>/g;
+    $$string
+        =~ s/:-\*/<img src="\/images\/kiss.gif" alt=":-*" border="0"\/>/g;
     $$string =~ s/:\(/<img src="\/images\/angry.gif" alt=":(" border="0"\/>/g;
     $$string =~ s/:\(/<img src="\/images\/angry.gif" alt=":(" border="0"\/>/g;
     $$string =~ s/\[Formatstring(\d+)\/\]/$formatString[$1]/egs;
 
-    if($ACCEPT_LANGUAGE eq 'de') {
+    if( $ACCEPT_LANGUAGE eq 'de' ) {
         $$string =~ s/\[en\](.*?)\[\/en\]//gs;
         $$string =~ s/\[de\](.*?)\[\/de\]/$1/gs;
     } else {
@@ -200,7 +208,7 @@ sub BBCODE {
 }
 
 sub formatString {
-    my ($string, $lang) = @_;
+    my ( $string, $lang ) = @_;
     use Syntax::Highlight::Engine::Kate;
     my $hl = new Syntax::Highlight::Engine::Kate(
         language      => $lang,
@@ -211,31 +219,37 @@ sub formatString {
 
         },
         format_table => {
-            Alert        => ["<span style=\"color:#0000ff\">",       "</span>"],
-            BaseN        => ["<span style=\"color:#007f00\">",       "</span>"],
-            BString      => ["<span style=\"color:#c9a7ff\">",       "</span>"],
-            Char         => ["<span style=\"color:#ff00ff\">",       "</span>"],
-            Comment      => ["<span style=\"color:#7f7f7f\"><i>",    "</i></span>"],
-            DataType     => ["<span style=\"color:#0000ff\">",       "</span>"],
-            DecVal       => ["<span style=\"color:#00007f\">",       "</span>"],
-            Error        => ["<span style=\"color:#ff0000\"><b><i>", "</i></b></span>"],
-            Float        => ["<span style=\"color:#00007f\">",       "</span>"],
-            Function     => ["<span style=\"color:#007f00\">",       "</span>"],
-            IString      => ["<span style=\"color:#ff0000\">",       ""],
-            Keyword      => ["<b>",                                  "</b>"],
-            Normal       => ["",                                     ""],
-            Operator     => ["<span style=\"color:#ffa500\">",       "</span>"],
-            Others       => ["<span style=\"color:#b03060\">",       "</span>"],
-            RegionMarker => ["<span style=\"color:#96b9ff\"><i>",    "</i></span>"],
-            Reserved     => ["<span style=\"color:#9b30ff\"><b>",    "</b></span>"],
-            String       => ["<span style=\"color:#ff0000\">",       "</span>"],
-            Variable     => ["<span style=\"color:#0000ff\"><b>",    "</b></span>"],
-            Warning      => ["<span style=\"color:#0000ff\"><b><i>", "</b></i></span>"],
+            Alert   => [ "<span style=\"color:#0000ff\">",    "</span>" ],
+            BaseN   => [ "<span style=\"color:#007f00\">",    "</span>" ],
+            BString => [ "<span style=\"color:#c9a7ff\">",    "</span>" ],
+            Char    => [ "<span style=\"color:#ff00ff\">",    "</span>" ],
+            Comment => [ "<span style=\"color:#7f7f7f\"><i>", "</i></span>" ],
+            DataType => [ "<span style=\"color:#0000ff\">", "</span>" ],
+            DecVal   => [ "<span style=\"color:#00007f\">", "</span>" ],
+            Error =>
+                [ "<span style=\"color:#ff0000\"><b><i>", "</i></b></span>" ],
+            Float    => [ "<span style=\"color:#00007f\">", "</span>" ],
+            Function => [ "<span style=\"color:#007f00\">", "</span>" ],
+            IString  => [ "<span style=\"color:#ff0000\">", "" ],
+            Keyword  => [ "<b>",                            "</b>" ],
+            Normal   => [ "",                               "" ],
+            Operator => [ "<span style=\"color:#ffa500\">", "</span>" ],
+            Others   => [ "<span style=\"color:#b03060\">", "</span>" ],
+            RegionMarker =>
+                [ "<span style=\"color:#96b9ff\"><i>", "</i></span>" ],
+            Reserved =>
+                [ "<span style=\"color:#9b30ff\"><b>", "</b></span>" ],
+            String => [ "<span style=\"color:#ff0000\">", "</span>" ],
+            Variable =>
+                [ "<span style=\"color:#0000ff\"><b>", "</b></span>" ],
+            Warning =>
+                [ "<span style=\"color:#0000ff\"><b><i>", "</b></i></span>" ],
         },
     );
     my $rplc = $hl->highlightText($string);
     $currentstring++;
-    $formatString[$currentstring] = qq(<div style="100%;overflow:auto"><pre>$rplc</pre></div>);
+    $formatString[$currentstring]
+        = qq(<div style="100%;overflow:auto"><pre>$rplc</pre></div>);
     return "[Formatstring$currentstring/]";
 }
 
